package com.ruoyi.system.service.impl;


import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.ActSupplies;
import com.ruoyi.system.domain.ActSuppliesDetails;
import com.ruoyi.system.mapper.ActSuppliesDetailsMapper;
import com.ruoyi.system.service.IActSuppliesDetailsService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 物料细分类管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-11
 */
@Service
public class ActSuppliesDetailsServiceImpl implements IActSuppliesDetailsService
{
    @Autowired
    private ActSuppliesDetailsMapper actSuppliesDetailsMapper;

    /**
     * 查询物料细分类管理
     * 
     * @param id 物料细分类管理ID
     * @return 物料细分类管理
     */
    @Override
    public ActSuppliesDetails selectActSuppliesDetailsById(Long id)
    {
        return actSuppliesDetailsMapper.selectActSuppliesDetailsById(id);
    }

    /**
     * 查询物料细分类管理列表
     * 
     * @param actSuppliesDetails 物料细分类管理
     * @return 物料细分类管理
     */
    @Override
    public List<ActSuppliesDetails> selectActSuppliesDetailsList(ActSuppliesDetails actSuppliesDetails)
    {
        return actSuppliesDetailsMapper.selectActSuppliesDetailsList(actSuppliesDetails);
    }

    /**
     * 新增物料细分类管理
     * 
     * @param actSuppliesDetails 物料细分类管理
     * @return 结果
     */
    @Override
    public int insertActSuppliesDetails(ActSuppliesDetails actSuppliesDetails)
    {
        String detailsName= actSuppliesDetails.getDetailsName();
        int countByDetailsName = actSuppliesDetailsMapper.countByDetailsName(detailsName);
        if(countByDetailsName > 0){
           /* String message = "添加六矿物料失败，名称已被占用！";
            System.out.println(message);*/
            /*throw new ServiceException(ServiceCode.ERR_CONFLICT,message);*/
            return 0;
        }
        actSuppliesDetails.setCreateTime(DateUtils.getNowDate());

        return actSuppliesDetailsMapper.insertActSuppliesDetails(actSuppliesDetails);
    }

    /**
     * 修改物料细分类管理
     * 
     * @param actSuppliesDetails 物料细分类管理
     * @return 结果
     */
    @Override
    public int updateActSuppliesDetails(ActSuppliesDetails actSuppliesDetails)
    {
        String detailsName= actSuppliesDetails.getDetailsName();
        int countByDetailsName = actSuppliesDetailsMapper.countByDetailsName(detailsName);
        if(countByDetailsName > 0){
          /*  String message = "修改六矿物料失败，名称已被占用！";
            System.out.println(message);*/
            /*throw new ServiceException(ServiceCode.ERR_CONFLICT,message);*/
            return 0;
        }

        actSuppliesDetails.setCreateTime(DateUtils.getNowDate());

        return actSuppliesDetailsMapper.updateActSuppliesDetails(actSuppliesDetails);
    }

    /**
     * 批量删除物料细分类管理
     * 
     * @param ids 需要删除的物料细分类管理ID
     * @return 结果
     */
    @Override
    public int deleteActSuppliesDetailsByIds(Long[] ids)
    {
        return actSuppliesDetailsMapper.deleteActSuppliesDetailsByIds(ids);
    }

    /**
     * 删除物料细分类管理信息
     * 
     * @param id 物料细分类管理ID
     * @return 结果
     */
    @Override
    public int deleteActSuppliesDetailsById(Long id)
    {
        return actSuppliesDetailsMapper.deleteActSuppliesDetailsById(id);
    }

    @Override
    public List<ActSupplies> saveSid() {
        return actSuppliesDetailsMapper.saveSid();
    }
    @Override
    public int setEnable(Long id, Integer status) {
        updateStatusById(id, status);
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("id", id);
        paramMap.put("status", status);
        return actSuppliesDetailsMapper.setEnable(paramMap);
    }

    @Override
    public int setDisable(Long id, Integer status) {
        updateStatusById(id, status);
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("id", id);
        paramMap.put("status", status);
        return actSuppliesDetailsMapper.setDisable(paramMap);
    }



    private int updateStatusById(Long id, Integer status){

        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("id", id);
        paramMap.put("status", status);

        return actSuppliesDetailsMapper.updateActSuppliesDetails(paramMap);

    }
}
