package com.ruoyi.system.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.ActSupplies;
import com.ruoyi.system.ex.ServiceException;
import com.ruoyi.system.mapper.ActSuppliesMapper;
import com.ruoyi.system.service.IActSuppliesService;
import com.ruoyi.system.web.ServiceCode;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.sql.rowset.serial.SerialException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import static jdk.nashorn.internal.runtime.regexp.joni.Config.log;

/**
 * 物料总分类管理Service业务层处理
 *
 * @author ruoyi
 * @date 2023-07-11
 */
@Service

public class ActSuppliesServiceImpl implements IActSuppliesService
{
    @Autowired
    private ActSuppliesMapper actSuppliesMapper;

    /**
     * 查询物料总分类管理
     *
     * @param id 物料总分类管理ID
     * @return 物料总分类管理
     */
    @Override
    public ActSupplies selectActSuppliesById(Long id)
    {
        return actSuppliesMapper.selectActSuppliesById(id);
    }

    /**
     * 查询物料总分类管理列表
     *
     * @param actSupplies 物料总分类管理
     * @return 物料总分类管理
     */
    @Override
    public List<ActSupplies> selectActSuppliesList(ActSupplies actSupplies)
    {
        return actSuppliesMapper.selectActSuppliesList(actSupplies);
    }

    /**
     * 新增物料总分类管理
     *
     * @param actSupplies 物料总分类管理
     * @return 结果
     */
    @Override
    public int insertActSupplies(ActSupplies actSupplies)
    {
        String suppliesName= actSupplies.getSuppliesName();
        int countBySuppliesName = actSuppliesMapper.countBySuppliesName(suppliesName);
        if(countBySuppliesName > 0){
          /*  String message = "添加物料总分类管理失败，名称已被占用！";
            System.out.println(message);*/
            /*throw new ServiceException(ServiceCode.ERR_CONFLICT,message);*/
            return 0;
        }

        actSupplies.setCreateTime(DateUtils.getNowDate());

         return actSuppliesMapper.insertActSupplies(actSupplies);
    }

    /**
     * 修改物料总分类管理
     *
     * @param actSupplies 物料总分类管理
     * @return 结果
     */
    @Override
    public int updateActSupplies(ActSupplies actSupplies)
    {
        String suppliesName= actSupplies.getSuppliesName();
        int countBySuppliesName = actSuppliesMapper.countBySuppliesName(suppliesName);
        if(countBySuppliesName > 0) {
          /*  String message = "修改物料总分类管理失败，新的名称已被占用！";
            System.out.println(message);*/
          /*  throw new ServiceException(ServiceCode.ERR_CONFLICT, message);*/
            return 0;
        }
        actSupplies.setUpdateTime(DateUtils.getNowDate());

         return actSuppliesMapper.updateActSupplies(actSupplies);
    }

    /**
     * 批量删除物料总分类管理
     *
     * @param ids 需要删除的物料总分类管理ID
     * @return 结果
     */
    @Override
    public int deleteActSuppliesByIds(Long[] ids)
    {
        return actSuppliesMapper.deleteActSuppliesByIds(ids);
    }

    /**
     * 删除物料总分类管理信息
     *
     * @param id 物料总分类管理ID
     * @return 结果
     */
    @Override
    public int deleteActSuppliesById(Long id)
    {
        return actSuppliesMapper.deleteActSuppliesById(id);
    }

    @Override
    public List<ActSupplies> options() {
        return actSuppliesMapper.options();
    }



    @Override
    public int setEnable(Long id, Integer status) {
        updateStatusById(id, status);
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("id", id);
        paramMap.put("status", status);
        return actSuppliesMapper.setEnable(paramMap);
    }

    @Override
    public int setDisable(Long id, Integer status) {
        updateStatusById(id, status);
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("id", id);
        paramMap.put("status", status);
        return actSuppliesMapper.setDisable(paramMap);
    }

    @Override
    public List<Integer> findall(Long[] ids) {
        return actSuppliesMapper.findall(ids);
    }

    @Override
    public List<Integer> findAllId(Long[] ids) {
        return actSuppliesMapper.findAllId(ids);
    }

    @Override
    public List<Integer> find(Long id) {
        return actSuppliesMapper.find(id);
    }

    @Override
    public List<Integer> findId(Long id) {
        return actSuppliesMapper.findId(id);
    }

    @Override
    public List<ActSupplies> selectActSuppliesListOne(ActSupplies actSupplies) {

        return actSuppliesMapper.selectActSuppliesListOne(actSupplies);
    }

    private int updateStatusById(Long id, Integer status){

        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("id", id);
        paramMap.put("status", status);

      return actSuppliesMapper.updateActSupplies(paramMap);
    }

}

